package com.winhc.bigdata.flink.java.jobs;

import cn.hutool.core.lang.Tuple;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.winhc.bigdata.flink.java.entity.CompanyDataReceive;
import com.winhc.bigdata.flink.java.entity.CompanyDataReceive2;
import com.winhc.bigdata.flink.java.entity.RowBaseDimEntity;
import com.winhc.bigdata.flink.java.entity.UpdateEntity;
import com.winhc.bigdata.flink.java.utils.KafkaSourceUtils;
import lombok.val;
import lombok.var;
import org.apache.flink.api.common.functions.FilterFunction;
import org.apache.flink.streaming.api.datastream.DataStreamSource;
import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
import org.apache.flink.streaming.connectors.kafka.FlinkKafkaConsumer;
import org.apache.flink.types.Row;

import java.util.stream.Collectors;

/**
 * @author π
 * @Description:
 * @date 2021/10/18 16:39
 */
public class TestJob2 {
    public static void main(String[] args) throws Exception {
        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
        //env.setParallelism(1);
        var kafkaSource = KafkaSourceUtils.getKafkaSource("flink_test", "xjk_test");
        var kafkaDS = env.addSource(kafkaSource);
        var receiveDS = kafkaDS.map(json -> JSON.parseObject(json, CompanyDataReceive2.class)).name("map name");
        var transformDS = receiveDS.map(c -> {
            val meta = c.getMeta();
            val data = c.getData();
            val base = c.getCompany();
            var dims = data
                    .entrySet()
                    .stream()
                    .map(
                            e ->
                                    new Tuple(e.getKey(),
                                            RowBaseDimEntity.of(
                                                    new Tuple(e.getKey(), e.getValue()),
                                                    new Tuple(meta.getCompanyId(), meta.getCompanyName()))
                                    )
                    )
                    .collect(Collectors.toMap(t -> (String) t.get(0), t -> (RowBaseDimEntity) t.get(1), (n, o) -> n));
            return new UpdateEntity(base, null, dims);
        }).name("to update");
        transformDS.print();
        env.execute("BaseJob");
    }
}
